import setuptools
setuptools.setup(name = 'updatedpip', version='1.0', author="VikdaBeast", description="Example pip package",
                 long_description = "This is necessary for winning", packages=setuptools.find_packages())